@@ -6,7 +6,6 @@ import (
 	"cloud.google.com/go/civil"
 	"github.com/getkin/kin-openapi/openapi3"
 	"github.com/tufin/oasdiff/diff"
-	"github.com/tufin/oasdiff/load"
 )
 
 const (
@@ -30,7 +29,7 @@ func APIRemovedCheck(diffReport *diff.Diff, operationsSources *diff.OperationsSo
 
 		for operation := range diffReport.PathsDiff.Base.Value(path).Operations() {
 			op := diffReport.PathsDiff.Base.Value(path).GetOperation(operation)
-			if change := checkAPIRemoval(APIPathRemovedWithoutDeprecationId, APIPathRemovedBeforeSunsetId, op, operationsSources, operation, path); change != nil {
+			if change := checkAPIRemoval(config, APIPathRemovedWithoutDeprecationId, APIPathRemovedBeforeSunsetId, op, operationsSources, operation, path); change != nil {
 				result = append(result, change)
 			}
 		}
@@ -42,7 +41,7 @@ func APIRemovedCheck(diffReport *diff.Diff, operationsSources *diff.OperationsSo
 		}
 		for _, operation := range pathItem.OperationsDiff.Deleted {
 			op := pathItem.Base.GetOperation(operation)
-			if change := checkAPIRemoval(APIRemovedWithoutDeprecationId, APIRemovedBeforeSunsetId, op, operationsSources, operation, path); change != nil {
+			if change := checkAPIRemoval(config, APIRemovedWithoutDeprecationId, APIRemovedBeforeSunsetId, op, operationsSources, operation, path); change != nil {
 				result = append(result, change)
 			}
 		}
@@ -51,16 +50,18 @@ func APIRemovedCheck(diffReport *diff.Diff, operationsSources *diff.OperationsSo
 	return result
 }
 
-func checkAPIRemoval(deprecationId, sunsetId string, op *openapi3.Operation, operationsSources *diff.OperationsSourcesMap, method, path string) Change {
+func checkAPIRemoval(config *Config, deprecationId, sunsetId string, op *openapi3.Operation, operationsSources *diff.OperationsSourcesMap, method, path string) Change {
 	if !op.Deprecated {
-		return ApiChange{
-			Id:          deprecationId,
-			Level:       ERR,
-			Operation:   method,
-			OperationId: op.OperationID,
-			Path:        path,
-			Source:      load.NewSource((*operationsSources)[op]),
-		}
+		return NewApiChange(
+			deprecationId,
+			config,
+			nil,
+			"",
+			operationsSources,
+			op,
+			method,
+			path,
+		)
 	}
 	sunset, ok := getSunset(op.Extensions)
 	if !ok {
@@ -70,31 +71,33 @@ func checkAPIRemoval(deprecationId, sunsetId string, op *openapi3.Operation, ope
 
 	date, err := getSunsetDate(sunset)
 	if err != nil {
-		return getAPIPathSunsetParse(op, operationsSources, method, path, err)
+		return getAPIPathSunsetParse(config, op, operationsSources, method, path, err)
 	}
 
 	if civil.DateOf(time.Now()).Before(date) {
-		return ApiChange{
-			Id:          sunsetId,
-			Level:       ERR,
-			Args:        []any{date},
-			Operation:   method,
-			OperationId: op.OperationID,
-			Path:        path,
-			Source:      load.NewSource((*operationsSources)[op]),
-		}
+		return NewApiChange(
+			sunsetId,
+			config,
+			[]any{date},
+			"",
+			operationsSources,
+			op,
+			method,
+			path,
+		)
 	}
 	return nil
 }
 
-func getAPIPathSunsetParse(operation *openapi3.Operation, operationsSources *diff.OperationsSourcesMap, method string, path string, err error) Change {
-	return ApiChange{
-		Id:          APIPathSunsetParseId,
-		Level:       ERR,
-		Args:        []any{err},
-		Operation:   method,
-		OperationId: operation.OperationID,
-		Path:        path,
-		Source:      load.NewSource((*operationsSources)[operation]),
-	}
+func getAPIPathSunsetParse(config *Config, operation *openapi3.Operation, operationsSources *diff.OperationsSourcesMap, method string, path string, err error) Change {
+	return NewApiChange(
+		APIPathSunsetParseId,
+		config,
+		[]any{err},
+		"",
+		operationsSources,
+		operation,
+		method,
+		path,
+	)
 }
