@@ -15,6 +15,10 @@ const (
 	ColorInvalid
 )
 
+func GetSupportedColorValues() []string {
+	return []string{"auto", "always", "never"}
+}
+
 func NewColorMode(color string) (ColorMode, error) {
 	switch color {
 	case "always":
