@@ -34,7 +34,7 @@ func (f HTMLFormatter) RenderDiff(diff *diff.Diff, opts RenderOpts) ([]byte, err
 }
 
 //go:embed templates/changelog.html
-var changelog string
+var changelogHtml string
 
 type TemplateData struct {
 	APIChanges      ChangesByEndpoint
@@ -43,13 +43,15 @@ type TemplateData struct {
 }
 
 func (f HTMLFormatter) RenderChangelog(changes checker.Changes, opts RenderOpts, specInfoPair *load.SpecInfoPair) ([]byte, error) {
-	tmpl := template.Must(template.New("changelog").Parse(changelog))
+	tmpl := template.Must(template.New("changelog").Parse(changelogHtml))
+	return ExecuteHtmlTemplate(tmpl, GroupChanges(changes, f.Localizer), specInfoPair)
+}
 
+func ExecuteHtmlTemplate(tmpl *template.Template, changes ChangesByEndpoint, specInfoPair *load.SpecInfoPair) ([]byte, error) {
 	var out bytes.Buffer
-	if err := tmpl.Execute(&out, TemplateData{GroupChanges(changes, f.Localizer), specInfoPair.GetBaseVersion(), specInfoPair.GetRevisionVersion()}); err != nil {
+	if err := tmpl.Execute(&out, TemplateData{changes, specInfoPair.GetBaseVersion(), specInfoPair.GetRevisionVersion()}); err != nil {
 		return nil, err
 	}
-
 	return out.Bytes(), nil
 }
 
